==> react-bootstrap-0.23.2.tgz: package/README.md <==
# react-bootstrap

[Bootstrap 3][bootstrap] components built with [React][react]

[![Travis Build Status][build-badge]][build]
[![Build status][appveyor-badge]][appveyor]

[![HuBoard][huboard-badge]][huboard]
[![Gitter][gitter-badge]][gitter]

[![NPM version][npm-badge]][npm]
[![Bower version][bower-badge]][bower]

[![Dependency Status][deps-badge]][deps]
[![devDependency Status][dev-deps-badge]][dev-deps]
[![peerDependency Status][peer-deps-badge]][peer-deps]

__Under active development - APIs will change.__ Check out the [1.0.0 Roadmap](https://github.com/react-bootstrap/react-bootstrap/wiki#100-roadmap) and [Contributing Guidelines][contributing] to see where you can help out. Prior to the 1.0.0 release, breaking changes should result in a Minor version bump.

## Docs

See the [documentation][documentation] with live editable examples.

## Related modules

- [react-router-bootstrap][react-router-bootstrap] - Integration with [react-router][react-router].
- [Complementary Tools][complementary-tools] - List of complementary tools that
  can be used with React.

## Local Setup

- Install the dependencies with `npm install`
- Run tests `npm test`
- Run tests in watch mode `npm run test-watch`
- Run the docs site in development mode with `npm run docs`. This will watch
  for file changes as you work. Simply refresh the page to see the updates.
- Build with `npm run build`

## Contributions

Yes please! See the [contributing guidelines][contributing] for details.

[bootstrap]: http://getbootstrap.com
[react]: http://facebook.github.io/react/

[documentation]: http://react-bootstrap.github.io
[contributing]: https://github.com/react-bootstrap/react-bootstrap/blob/master/CONTRIBUTING.md

[build-badge]: https://travis-ci.org/react-bootstrap/react-bootstrap.svg
[build]: https://travis-ci.org/react-bootstrap/react-bootstrap

[npm-badge]: https://badge.fury.io/js/react-bootstrap.svg
[npm]: http://badge.fury.io/js/react-bootstrap

[bower-badge]: https://badge.fury.io/bo/react-bootstrap.svg
[bower]: http://badge.fury.io/bo/react-bootstrap 

[gitter-badge]: https://badges.gitter.im/Join%20Chat.svg
[gitter]: https://gitter.im/react-bootstrap/react-bootstrap?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

[deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap.svg
[deps]: https://david-dm.org/react-bootstrap/react-bootstrap

[dev-deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap/dev-status.svg
[dev-deps]: https://david-dm.org/react-bootstrap/react-bootstrap#info=devDependencies

[peer-deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap/peer-status.svg
[peer-deps]: https://david-dm.org/react-bootstrap/react-bootstrap#info=peerDependencies 

[react-router-bootstrap]: https://github.com/react-bootstrap/react-router-bootstrap
[react-router]: https://github.com/rackt/react-router

[complementary-tools]: https://github.com/facebook/react/wiki/Complementary-Tools

[huboard-badge]: https://img.shields.io/badge/Hu-Board-7965cc.svg
[huboard]: https://huboard.com/react-bootstrap/react-bootstrap

[appveyor-badge]: https://ci.appveyor.com/api/projects/status/ylitpyo6n5yq1s6i/branch/master?svg=true
[appveyor]: https://ci.appveyor.com/project/react-bootstrap/react-bootstrap/branch/master

==> react-bootstrap-0.23.5.tgz: package/README.md <==
# react-bootstrap

[Bootstrap 3][bootstrap] components built with [React][react]

[![Travis Build Status][build-badge]][build]
[![Build status][appveyor-badge]][appveyor]

[![HuBoard][huboard-badge]][huboard]
[![Gitter][gitter-badge]][gitter]

[![NPM version][npm-badge]][npm]
[![Bower version][bower-badge]][bower]

[![Dependency Status][deps-badge]][deps]
[![devDependency Status][dev-deps-badge]][dev-deps]
[![peerDependency Status][peer-deps-badge]][peer-deps]

__Under active development - APIs will change.__ Check out the [1.0.0 Roadmap](https://github.com/react-bootstrap/react-bootstrap/wiki#100-roadmap) and [Contributing Guidelines][contributing] to see where you can help out. Prior to the 1.0.0 release, breaking changes should result in a Minor version bump.

## Docs

See the [documentation][documentation] with live editable examples.

## Related modules

- [react-router-bootstrap][react-router-bootstrap] - Integration with [react-router][react-router].
- [Complementary Tools][complementary-tools] - List of complementary tools that
  can be used with React.

## Local Setup

- Install the dependencies with `npm install`
- Run tests `npm test`
- Run tests in watch mode `npm run test-watch`
- Run the docs site in development mode with `npm run docs`. This will watch
  for file changes as you work. Simply refresh the page to see the updates.
- Build with `npm run build`

## Contributions

Yes please! See the [contributing guidelines][contributing] for details.

[bootstrap]: http://getbootstrap.com
[react]: http://facebook.github.io/react/

[documentation]: http://react-bootstrap.github.io
[contributing]: https://github.com/react-bootstrap/react-bootstrap/blob/master/CONTRIBUTING.md

[build-badge]: https://travis-ci.org/react-bootstrap/react-bootstrap.svg?branch=master
[build]: https://travis-ci.org/react-bootstrap/react-bootstrap

[npm-badge]: https://badge.fury.io/js/react-bootstrap.svg
[npm]: http://badge.fury.io/js/react-bootstrap

[bower-badge]: https://badge.fury.io/bo/react-bootstrap.svg
[bower]: http://badge.fury.io/bo/react-bootstrap 

[gitter-badge]: https://badges.gitter.im/Join%20Chat.svg
[gitter]: https://gitter.im/react-bootstrap/react-bootstrap?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge

[deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap.svg
[deps]: https://david-dm.org/react-bootstrap/react-bootstrap

[dev-deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap/dev-status.svg
[dev-deps]: https://david-dm.org/react-bootstrap/react-bootstrap#info=devDependencies

[peer-deps-badge]: https://david-dm.org/react-bootstrap/react-bootstrap/peer-status.svg
[peer-deps]: https://david-dm.org/react-bootstrap/react-bootstrap#info=peerDependencies 

[react-router-bootstrap]: https://github.com/react-bootstrap/react-router-bootstrap
[react-router]: https://github.com/rackt/react-router

[complementary-tools]: https://github.com/facebook/react/wiki/Complementary-Tools

[huboard-badge]: https://img.shields.io/badge/Hu-Board-7965cc.svg
[huboard]: https://huboard.com/react-bootstrap/react-bootstrap

[appveyor-badge]: https://ci.appveyor.com/api/projects/status/ylitpyo6n5yq1s6i/branch/master?svg=true
[appveyor]: https://ci.appveyor.com/project/react-bootstrap/react-bootstrap/branch/master
